@@ -49,8 +49,8 @@ class ModifiedRepositoryListHandler(IPythonHandler):
                     logger.info('File is not under Git repository: ' + file['path'])
 
             for repo in repositories:
-                path = repo.working_dir
                 name = os.path.basename(path)
+                path = repo.working_dir.replace(os.sep, '/')
                 response.append({
                     "path": path,
                     "name": name
@@ -171,6 +171,6 @@ class ServerConfigHandler(IPythonHandler):
             raise RuntimeError('Could not read server_root_dir from Jupyter!')
 
         result = {
-            'server_root_dir': os.path.expanduser(self.server_root_dir)
+            'server_root_dir': os.path.expanduser(self.server_root_dir).replace(os.sep, '/')
         }
         self.finish(json.dumps(result))
